@@ -14,7 +14,7 @@ env.vm_path = "/Users/dom/VM/devcoop"
 env.locale = 'fr_FR.UTF-8'
 
 #Paramétres par défaut
-domaine = "localhost"
+domain = "localhost"
 projet = "coop_test"
 alias = "coop_test"
 
@@ -24,6 +24,14 @@ pgpass = '123456'
 env.websrv = 1
 
 
+@task
+def test():
+    print(yellow('run() test...'))
+    run('date')
+    print(yellow('sudo() test...'))
+    sudo('date')
+
+
 def pretty_apt(pkglist):
     for pkg in (pkglist):
         icanhaz.deb.package(pkg)
@@ -35,6 +43,7 @@ def pretty_pip(pkglist):
         icanhaz.python.install(pkg)
         print(green(u'Module Python "' + unicode(pkg) + u'" : installé.'))
 
+
 @task
 def local_vm():
     '''First command to use for a Vagrant VM'''
@@ -96,8 +105,8 @@ def project():
 
 
 def domain():
-    if 'domaine' not in env.keys():
-        prompt('DNS:', default=domaine, key='domaine')
+    if 'domain' not in env.keys():
+        prompt('DNS:', default=domain, key='domain')
 
 #prompt('Config : (1)Apache seul ou (2)Apache+Nginx :',key='websrv',validate=int,default=env.websrv)
 
@@ -228,7 +237,7 @@ def coop_project():
                         default=False):
                 with cd('projects/'):
                     with prefix('workon %(projet)s' % env):
-                        run('coop-admin.py startproject %(projet)s --domain %(domaine)s' % env)
+                        run('coop-admin.py startproject %(projet)s --domain %(domain)s' % env)
                         print(green('Projet Django-coop "%(projet)s" : Installé.' % env))
                         # coop-admin scripts creates the WSGI script so we won't call django_wsgi()
                 with cd('projects/%(projet)s' % env):
@@ -247,19 +256,19 @@ def apache_vhost():
     if(env.websrv == 1):
         vhost_context = {
             'user': env.user,
-            'domain': env.domaine,
+            'domain': env.domain,
             'projet': env.projet
         }
         import coop
         coop_path = coop.__path__[0]
         upload_template('%s/fab_templates/vhost.txt' % coop_path,
-                        '/etc/apache2/sites-available/%(domaine)s' % env,
+                        '/etc/apache2/sites-available/%(domain)s' % env,
                         context=vhost_context, use_sudo=True)
         with cd('/etc/apache2/'):
             with settings(hide('warnings', 'running', 'stdout', 'stderr')):
-                sudo('rm sites-enabled/%(domaine)s' % env)
-            sudo('ln -s `pwd`/sites-available/%(domaine)s sites-enabled/%(domaine)s' % env)
-            print(green('VirtualHost Apache pour %(domaine)s : OK.' % env))
+                sudo('rm sites-enabled/%(domain)s' % env)
+            sudo('ln -s `pwd`/sites-available/%(domain)s sites-enabled/%(domain)s' % env)
+            print(green('VirtualHost Apache pour %(domain)s : OK.' % env))
     elif(env.websrv == 2):
         print(red('Script de déploiement pas encore écrit !!!'))  # TODO
     sudo('apachectl restart')
@@ -351,17 +360,18 @@ def apache_setup():
     #virer le site par défaut
     with cd('/etc/apache2/'):
         if not contains('apache2.conf', 'ServerName localhost', use_sudo=True):
-            if not contains('apache2.conf', 'ServerName %(domaine)s' % env, use_sudo=True):
-                sudo("echo 'ServerName %(domaine)s'|cat - apache2.conf > /tmp/out && mv /tmp/out apache2.conf" % env)
+            if not contains('apache2.conf', 'ServerName %(domain)s' % env, use_sudo=True):
+                sudo("echo 'ServerName %(domain)s'|cat - apache2.conf > /tmp/out && mv /tmp/out apache2.conf" % env)
     with cd('/etc/apache2/sites-enabled/'):
         if exists('000-default'):
             sudo('rm 000-default')
             print(green('Site par défaut d’Apache supprimé'))
 
 
+@task
 def create_pg_db():
     '''Créer une base de données postgres au nom du projet'''
-    with settings(show('user'), hide('warnings', 'running', 'stdout', 'stderr')):
+    with settings(show('user')):#, hide('warnings', 'running', 'stdout', 'stderr')):
         project()
         icanhaz.postgres.database(env.projet, env.user, template='template_postgis', locale=env.locale)
         print(green('Création base de données PostgreSQL nommée "%(projet)s" : OK.' % env))
@@ -385,6 +395,9 @@ def virtualenv_setup():
         print(green('Dossier "projects" créé.'))
     # sur .bashrc et pas .bashrc
     # + fix pour https://bitbucket.org/dhellmann/virtualenvwrapper/issue/62/hooklog-permissions
+    run('touch .bash_login')
+    if not contains('.bash_login', '. .bashrc'):
+        append('.bash_login', 'if [ $USER == %(user)s ]; then' % env)
     if not contains('.bashrc', 'WORKON_HOME'):
         append('.bashrc', 'if [ $USER == %(user)s ]; then' % env)
         append('.bashrc', '    export WORKON_HOME=$HOME/.virtualenvs')
