@@ -14,8 +14,9 @@ urlpatterns = patterns('',
     url(r'^categorie/(?P<slug>[\w-]+)/$', 'coop.org.views.org_category_detail', name="org_category_detail"),
 
     url(r'^global_map$', 'coop.org.views.global_map', name="org_global_map"),
-    url(r'^(?P<slug>[\w-]+)/$', 'coop.org.views.org_detail_view', name="org_detail"),
-    url(r'^(?P<slug>[\w-]+)/edit/$', 'coop.org.views.org_edit', name="org_edit"),
+    url(r'^(?P<slug>[\w-]+)/$', 'coop.org.views.org_detail', name="org_detail"),
+    url(r'^(?P<slug>[\w-]+)/edition/$', 'coop.org.views.org_edit', name="org_edit"),
+    url(r'^(?P<slug>[\w-]+)/edition/annuler/$', 'coop.org.views.org_edit_cancel', name='org_edit_cancel'),
 
     #url(r'^role/(?P<slug>[\w-]+)/$', 'coop.org.views.role_detail', name="role_detail"),
 
