@@ -2,8 +2,6 @@
 
 from coop_local.settings import PROJECT_PATH, PROJECT_NAME
 
-D2RQ_PORT = 8080
-D2RQ_ROOT = 'http://localhost:8080/' + PROJECT_NAME + '/'
 
 # Not used: to set this variable here, weneed to import Site
 PUSH_HUB = ''
